// Define the pin for the hall effect sensor
const int hallEffectPin = D8;

// Array of messages
const char* messages[] = {"$10", "$100", "000", "TRY AGAIN!"};
const int numMessages = 4;

// Variable to store the current message index
int messageIndex = 0;

// Flag to track whether the sensor was already triggered
bool sensorTriggered = false;

void setup() {
  // Initialize serial communication
  Serial.begin(9600);

  // Set the hall effect sensor pin as input
  pinMode(hallEffectPin, INPUT);
}

void loop() {
  // Check if data is available on the serial port
  if (Serial.available()) {
    char incomingByte = Serial.read();
    // If a 'R' is received, reset the message index
    if (incomingByte == 'R') {
      messageIndex = 0;
      Serial.println("LET'S START!");
    }
  }

  // Read the state of the hall effect sensor
  int sensorState = digitalRead(hallEffectPin);

  // If the sensor detects a magnet (LOW state) and it wasn't triggered before
  if (sensorState == LOW && !sensorTriggered) {
    // Increment the message index
    messageIndex++;
    if (messageIndex >= numMessages) {
      messageIndex = 0;
    }

    // Print the current message
    //Serial.print("Message: ");
    Serial.println(messages[messageIndex]);

    // Set the sensor triggered flag to true
    sensorTriggered = true;
  }
  // If the sensor is not detecting a magnet (HIGH state), reset the sensor triggered flag to false
  if (sensorState == HIGH) {
    sensorTriggered = false;
  }

  // A short delay to prevent rapid counting due to sensor noise
  //delay(100);
}
